==> xraybinaryorbit-0.2.4.tar.gz: xraybinaryorbit-0.2.4/test/test_absorption_column_through_orbit_theoretical.py <==
import pytest
import numpy as np
from xraybinaryorbit import absorption_column_through_orbit_theoretical

# Mock functions for _manage_parameters and _orbital_phase_to_time
def _mock_manage_parameters(parameter_names, context):
    """Mock function to return dummy fixed values for parameters."""
    return [10, 100, 0.5, 30, 45, 1.2, 1.5, 0.8, 500, 2e-5, 0.8]  # Replace with reasonable defaults

def _mock_orbital_phase_to_time(th, iphase, semimajor, orbitalperiod, eccentricity, periapsis, Rstar, Mstar1, Mstar2, precision=0.01):
    """Mock function to simulate time calculation based on orbital phase."""
    time = th * orbitalperiod * 24 * 60 * 60  # Convert phase to time in seconds
    return th, time, None

# Test for the default case with plot generation disabled
def test_absorption_column_through_orbit_theoretical_default(monkeypatch):
    # Patch the internal functions that are not available for direct testing
    monkeypatch.setattr('xraybinaryorbit._manage_parameters', _mock_manage_parameters)
    monkeypatch.setattr('xraybinaryorbit._orbital_phase_to_time', _mock_orbital_phase_to_time)

    # Run the function
    time_out, phase_out, nh_out = absorption_column_through_orbit_theoretical(resolution=0.01, show_plot=False)

    # Assert outputs
    assert len(time_out) == len(phase_out) == len(nh_out), "The output arrays should have the same length."
    assert isinstance(nh_out, np.ndarray), "NH1 should be a NumPy array."
    assert len(nh_out) > 0, "The NH1 array should not be empty."
    assert nh_out.min() >= 0, "The NH1 values should be non-negative."

# Test for higher resolution
def test_absorption_column_through_orbit_theoretical_high_resolution(monkeypatch):
    # Patch the internal functions
    monkeypatch.setattr('xraybinaryorbit._manage_parameters', _mock_manage_parameters)
    monkeypatch.setattr('xraybinaryorbit._orbital_phase_to_time', _mock_orbital_phase_to_time)

    # Run the function with higher resolution
    time_out, phase_out, nh_out = absorption_column_through_orbit_theoretical(resolution=0.001, show_plot=False)

    # Assert outputs
    assert len(time_out) == len(phase_out) == len(nh_out), "The output arrays should have the same length."
    assert isinstance(nh_out, np.ndarray), "NH1 should be a NumPy array."
    # Modify the assertion condition to handle cases where the length is exactly 1000
    assert len(nh_out) >= 1000, "The NH1 array should have at least 1000 points with higher resolution."

# Test for plot generation
def test_absorption_column_through_orbit_theoretical_plot(monkeypatch):
    # Patch the internal functions
    monkeypatch.setattr('xraybinaryorbit._manage_parameters', _mock_manage_parameters)
    monkeypatch.setattr('xraybinaryorbit._orbital_phase_to_time', _mock_orbital_phase_to_time)

    # Run the function with plot generation enabled (it should not raise any exceptions)
    try:
        absorption_column_through_orbit_theoretical(resolution=0.01, show_plot=True)
    except Exception as e:
        pytest.fail(f"Plot generation failed with error: {e}")

==> xraybinaryorbit-1.0.1.tar.gz: xraybinaryorbit-1.0.1/test/test_absorption_column_through_orbit_theoretical.py <==
import pytest
from xraybinaryorbit import *

# Test for the default case with plot generation disabled
def test_absorption_column_through_orbit_theoretical_default():

    # Run the function
    time_out, phase_out, nh_out = absorption_column_through_orbit_theoretical(resolution=0.01, show_plot=False, load_directly=True)

    # Assert outputs
    assert len(time_out) == len(phase_out) == len(nh_out), "The output arrays should have the same length."
    assert isinstance(nh_out, np.ndarray), "NH1 should be a NumPy array."
    assert len(nh_out) > 0, "The NH1 array should not be empty."
    assert nh_out.min() >= 0, "The NH1 values should be non-negative."


# Test for higher resolution
def test_absorption_column_through_orbit_theoretical_high_resolution():

    # Run the function with higher resolution
    time_out, phase_out, nh_out = absorption_column_through_orbit_theoretical(resolution=0.001, show_plot=False, load_directly=True)

    # Assert outputs
    assert len(time_out) == len(phase_out) == len(nh_out), "The output arrays should have the same length."
    assert isinstance(nh_out, np.ndarray), "NH1 should be a NumPy array."
    assert len(nh_out) >= 1000, "The NH1 array should have at least 1000 points with higher resolution."
    assert nh_out.min() >= 0, "The NH1 values should be non-negative."


# Test for plot generation (it should not raise any exceptions)
def test_absorption_column_through_orbit_theoretical_plot():

    # Run the function with plot generation enabled (it should not raise any exceptions)
    try:
        absorption_column_through_orbit_theoretical(resolution=0.01, show_plot=True, load_directly=True)
    except Exception as e:
        pytest.fail(f"Plot generation failed with error: {e}")
